@@ -37,8 +37,7 @@ struct dsu {
 
     int leader(int a) {
         assert(0 <= a && a < _n);
-        if (parent_or_size[a] < 0) return a;
-        return parent_or_size[a] = leader(parent_or_size[a]);
+        return _leader(a);
     }
 
     int size(int a) {
@@ -71,6 +70,11 @@ struct dsu {
     // root node: -1 * component size
     // otherwise: parent
     std::vector<int> parent_or_size;
+
+    int _leader(int a) {
+        if (parent_or_size[a] < 0) return a;
+        return parent_or_size[a] = _leader(parent_or_size[a]);
+    }
 };
 
 }  // namespace atcoder
