@@ -11,7 +11,9 @@ namespace atcoder {
 struct scc_graph {
   public:
     scc_graph() : internal(0) {}
-    explicit scc_graph(int n) : internal(n) {}
+    explicit scc_graph(int n) : internal(n) {
+        assert(n >= 0);
+    }
 
     void add_edge(int from, int to) {
         int n = internal.num_vertices();
